==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/sh/article_images.php <==
<?php
regGS("You do not have the right to add images.", "Nemate pravo da dodajete slike.");
regGS("Image information", "Podaci o slici");
regGS("Attach New Image", "Zakači novu sliku");
regGS("Attach Image To Article", "Prikači sliku uz članak");
regGS("Attach Existing Image", "Prikači postojeću sliku");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Nemate pravo da menjate članak. Možete menjati samo svoje članke, a predatim člancima status može promeniti samo ovlašćeni korsnik.");
regGS("Add New Image", "Dodaj novu sliku");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Datum<br><small>(gggg-mm-dd)</small>");
regGS("Please enter a number for the image.", "Unesite broj za ovu sliku.");
regGS("Please enter a description for the image.", "Unesite opis slike.");
regGS("You must select an image file to upload.", "Morate izabrati sliku koju želite da aploudujete.");
regGS("Change image information", "Promeni podatke o slici");
regGS("You do not have the right to add images", "Nemate pravo da dodajete slike");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Da li ste sigurni da želite da uklonite sliku \'$1\' iz članka?");
regGS("Delete image $1", "Izbriši sliku $1");
regGS("Click one of the ", "Kliknite na jedan od ponuđenih 'dodaj sliku' linkova.");
regGS("Are you sure you want to delete the image '$1'?", "Da li ste sigurni da želite da obrišete sliku $1?");
regGS("Unlink image $1", "Ukloni vezu slike $1");
?>

==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sh/article_images.php <==
<?php 
regGS("You do not have the right to change image information.", "");
regGS("The image number specified is already in use.", "");
regGS("The image has been removed from the article.", "");
regGS("Image '$1' updated.", "");
regGS("Image '$1' added.", "");
regGS("Edit article", "Uredi tekst");
regGS("You do not have the right to attach images to articles.", "Nemate pravo da kačite slike uz tekstove.");
regGS("You do not have the right to add images.", "Nemate pravo da dodajete slike.");
regGS("Image information", "Podaci o slici");
regGS("Attach New Image", "Zakači novu sliku");
regGS("Attach Image To Article", "Prikači sliku uz tekst");
regGS("Attach Existing Image", "Prikači postojeću sliku");
regGS("Add New Image", "Dodaj novu sliku");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Datum<br><small>(gggg-mm-dd)</small>");
regGS("Please enter a number for the image.", "Unesite broj za ovu sliku.");
regGS("Please enter a description for the image.", "Unesite opis slike.");
regGS("You must select an image file to upload.", "Morate izabrati sliku koju želite da aploudujete.");
regGS("Change image information", "Promeni podatke o slici");
regGS("You do not have the right to add images", "Nemate pravo da dodajete slike");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Da li ste sigurni da želite da uklonite sliku \'$1\' iz članka?");
regGS("Delete image $1", "Izbriši sliku $1");
regGS("Click one of the ", "Kliknite na jedan od ponuđenih 'dodaj sliku' linkova.");
regGS("Are you sure you want to delete the image '$1'?", "Da li ste sigurni da želite da obrišete sliku $1?");
regGS("Unlink image $1", "Ukloni vezu slike $1");
?>
